@@ -376,6 +376,9 @@ Desc decoder_profiles[] = {
 {"HEVC_MAIN_444",               VDP_DECODER_PROFILE_HEVC_MAIN_444},
 {"HEVC_MAIN_444_10",            VDP_DECODER_PROFILE_HEVC_MAIN_444_10},
 {"HEVC_MAIN_444_12",            VDP_DECODER_PROFILE_HEVC_MAIN_444_12},
+{"AV1_MAIN",                    VDP_DECODER_PROFILE_AV1_MAIN},
+{"AV1_HIGH",                    VDP_DECODER_PROFILE_AV1_HIGH},
+{"AV1_PROFESSIONAL",            VDP_DECODER_PROFILE_AV1_PROFESSIONAL},
 
 };
 const size_t decoder_profile_count = sizeof(decoder_profiles)/sizeof(Desc);
